Crate hexga_number

Crate hexga_number 

Modules

prelude

Macros

map_on
A powerful macro to impl other macros for the given types.
map_on_constant
map_on_constant_policy
map_on_constant_unit
map_on_float
f32, f64
map_on_integer
(u8, u16, u32, u64, usize) + (i8, i16, i32, i64, isize)
map_on_integer_signed
i8, i16, i32, i64, isize
map_on_integer_unsigned
u8, u16, u32, u64, usize
map_on_number
(u8, u16, u32, u64, usize) + (i8, i16, i32, i64, isize) + (f32, f64)
map_on_number_and_bool
(u8, u16, u32, u64, usize) + (i8, i16, i32, i64, isize) + (f32, f64) + (bool)
map_on_number_and_bool_and_char
(u8, u16, u32, u64, usize) + (i8, i16, i32, i64, isize) + (f32, f64) + (bool) + (char)
map_on_operator_assign
(AddAssign, SubAssign) + (MulAssign, DivAssign, RemAssign) + (BitOrAssign, BitAndAssign, ShlAssign, ShrAssign)
map_on_operator_assign_arithmetic
(AddAssign, SubAssign) + (MulAssign, DivAssign, RemAssign)
map_on_operator_assign_arithmetic_unit
AddAssign, SubAssign
map_on_operator_assign_bit
BitOrAssign, BitAndAssign, ShlAssign, ShrAssign
map_on_operator_binary
(Add, Sub) + (Mul, Div, Rem) + (BitOr, BitAnd, Shl, Shr)
map_on_operator_binary_arithmetic
(Add, Sub) + (Mul, Div, Rem)
map_on_operator_binary_arithmetic_unit
Add, Sub
map_on_operator_binary_bit
BitOr, BitAnd, Shl, Shr
map_on_operator_unary
(Not) + (Neg, Abs)
map_on_operator_unary_arithmetic_unit
Neg, Abs
map_on_operator_unary_bit
Not
map_on_std_fmt
Macro for mapping over all standard formatting traits:
map_on_std_fmt_without_debug
Macro for mapping over all standard formatting traits except [std::fmt::Debug]:
map_on_tuple
A powerful macro to impl other macros for tuple, up to 16 element (may change).

Structs

ConstantHalf
ConstantInfinity
ConstantMax
ConstantMin
ConstantMinusInfinity
ConstantMinusOne
ConstantNaN
ConstantOne
ConstantZero

Enums

NumberType
OverflowPolicy

Traits

Constant
Constant Policy Value
Decrement
The -1 operation
Half
Define the 0.5 representation
Increment
The +1 operation
Infinity
MaxValue
MinValue
MinusInfinity
MinusOne
Define the -1 representation
MinusOneIter
NaNValue
Define the Not a Number (NaN) representation
One
Define the 1 representation : The neutral element of the multiplication such that x * X::ONE = x
OneIter
OverflowBehavior
PrimitiveType
UnwrapZero
Zero
Define the 0 representation : The absorbing element of the multiplication such that x * X::ZERO = X::ZERO
ZeroIter

Functions

half
minus_one
one
zero